==> bonita-server-10.2.0-sources.jar: org/bonitasoft/engine/tenant/ChangesServicesStateCallable.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.tenant;

import java.io.Serializable;
import java.util.concurrent.Callable;

import org.bonitasoft.engine.service.ServiceAccessor;
import org.bonitasoft.engine.service.ServiceAccessorSingleton;

/**
 * @author Emmanuel Duchastenier
 */
class ChangesServicesStateCallable implements Callable<Void>, Serializable {

    private final TenantServicesManager.ServiceAction action;

    public ChangesServicesStateCallable(TenantServicesManager.ServiceAction action) {
        this.action = action;
    }

    @Override
    public Void call() throws Exception {
        ServiceAccessor serviceAccessor = ServiceAccessorSingleton.getInstance();
        TenantServicesManager tenantServicesManager = serviceAccessor.getTenantServicesManager();
        TenantStateManager tenantStateManager = serviceAccessor.getTenantStateManager();
        return tenantStateManager.executeTenantManagementOperation(
                "Executing received " + action.name().toLowerCase() + " operation", () -> {
                    switch (action) {
                        case START:
                            tenantServicesManager.start();
                            break;
                        case STOP:
                            tenantServicesManager.stop();
                            break;
                        case PAUSE:
                            tenantServicesManager.pause();
                            break;
                        case RESUME:
                            tenantServicesManager.resume();
                            break;
                    }
                    return null;
                });
    }
}

==> bonita-server-10.3.0-sources.jar: org/bonitasoft/engine/tenant/ChangesServicesStateCallable.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.tenant;

import java.io.Serializable;
import java.util.concurrent.Callable;

import org.bonitasoft.engine.service.ServiceAccessor;
import org.bonitasoft.engine.service.ServiceAccessorSingleton;

/**
 * @author Emmanuel Duchastenier
 */
class ChangesServicesStateCallable implements Callable<Void>, Serializable {

    private final TenantServicesManager.ServiceAction action;

    public ChangesServicesStateCallable(TenantServicesManager.ServiceAction action) {
        this.action = action;
    }

    @Override
    public Void call() throws Exception {
        ServiceAccessor serviceAccessor = ServiceAccessorSingleton.getInstance();
        TenantServicesManager tenantServicesManager = serviceAccessor.getTenantServicesManager();
        TenantStateManager tenantStateManager = serviceAccessor.getTenantStateManager();
        return tenantStateManager.executeManagementOperation(
                "Executing received " + action.name().toLowerCase() + " operation", () -> {
                    switch (action) {
                        case START:
                            tenantServicesManager.start();
                            break;
                        case STOP:
                            tenantServicesManager.stop();
                            break;
                        case PAUSE:
                            tenantServicesManager.pause();
                            break;
                        case RESUME:
                            tenantServicesManager.resume();
                            break;
                    }
                    return null;
                });
    }
}
